summaryrefslogtreecommitdiffstats
path: root/winsup/cygwin/profil.c
diff options
context:
space:
mode:
authorCorinna Vinschen <corinna@vinschen.de>2016-03-24 16:39:15 +0100
committerCorinna Vinschen <corinna@vinschen.de>2016-03-24 16:39:15 +0100
commitacc5f02ce8637bb6b395292fa259d20c296d8aa8 (patch)
tree318ee689b36a0decbd28f2a715b2c61ed3ab9bea /winsup/cygwin/profil.c
parent6ba2b53c53260323039d7f872034991e6706a20b (diff)
downloadcygnal-acc5f02ce8637bb6b395292fa259d20c296d8aa8.tar.gz
cygnal-acc5f02ce8637bb6b395292fa259d20c296d8aa8.tar.bz2
cygnal-acc5f02ce8637bb6b395292fa259d20c296d8aa8.zip
Throughout Cygwin, use u_intN_t or uintN_t
Don't use u_char, u_short, u_int or u_long in Cygwin, unless it refers to the Winsock types. Use u_intN_t in BSD-based sources, unsigned char where strings are concerned, uintN_t otherwise. Also: * net.cc: Fix comment, we're not using u_long anymore. Signed-off-by: Corinna Vinschen <corinna@vinschen.de>
Diffstat (limited to 'winsup/cygwin/profil.c')
-rw-r--r--winsup/cygwin/profil.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/winsup/cygwin/profil.c b/winsup/cygwin/profil.c
index 2d7d6e394..2d8fdc0ff 100644
--- a/winsup/cygwin/profil.c
+++ b/winsup/cygwin/profil.c
@@ -205,7 +205,7 @@ profile_child (void)
* Start or stop profiling.
*
* Profiling data goes into the SAMPLES buffer of size SIZE (which is treated
* as an array of u_shorts of size SIZE/2).
*
* Each bin represents a range of pc addresses from OFFSET. The number
* of pc addresses in a bin depends on SCALE. (A scale of 65536 maps
@@ -215,7 +215,7 @@ profile_child (void)
*/
int
profile_ctl (struct profinfo * p, char *samples, size_t size,
- size_t offset, u_int scale)
+ size_t offset, uint32_t scale)
{
size_t maxbin;
@@ -231,7 +231,7 @@ profile_ctl (struct profinfo * p, char *samples, size_t size,
memset (samples, 0, size);
memset (p, 0, sizeof *p);
maxbin = size >> 1;
- prof.counter = (u_short *) samples;
+ prof.counter = (uint16_t *) samples;
prof.lowpc = offset;
prof.highpc = PROFADDR (maxbin, offset, scale);
prof.scale = scale;
@@ -250,7 +250,7 @@ profile_ctl (struct profinfo * p, char *samples, size_t size,
The word pointed to by this address is incremented. Buf is unused. */
int
-profil (char *samples, size_t size, size_t offset, u_int scale)
+profil (char *samples, size_t size, size_t offset, uint32_t scale)
{
return profile_ctl (&prof, samples, size, offset, scale);
}
@@ -205,7 +205,7 @@ profile_child (void)
*
* Profiling data goes into the SAMPLES buffer of size SIZE (which is treated
- * as an array of u_shorts of size SIZE/2).
+ * as an array of uint16_t of size SIZE/2).
*
* Each bin represents a range of pc addresses from OFFSET. The number